---
title: 결제유형
category: 서비스 종류 (결제대행사별 지원서비스) > 결제유형 > 결제유형
seo:
  title: 결제유형
  description: >-
    포트원에서 제공하는 결제 유형입니다. 결제 유형에 따라 지원하는 결제대행사가 상이하므로 결제대행사를 고르기 전 연동 개발 방식을 정한 후
    그에 맞는 결제대행사를 결정하시길 권장드립니다.
  keywords:
    - 결제유형
    - 일반결제
    - 정기결제
    - 빌링결제
    - 해외결제
tags:
  - 공통
pgCompanies:
  - 공통
searchTags:
  - 결제유형
  - 일반결제
  - 정기결제
  - 빌링결제
  - 해외결제
---

<Callout content="포트원에서 제공하는 결제 유형입니다.
결제 유형에 따라 지원하는 결제대행사가 상이하므로 결제대행사를 고르기 전 연동 개발 방식을 정한 후 그에 맞는 결제대행사를 결정하시길 권장드립니다." />

## <Highlight text="일반결제" />

일반결제는 일회성 결제라고도 불리며 고객이 결제 수단을 선택한 후 결제를 진행하는 방식을 의미합니다.

일반적으로 온라인에서 사용되는 전자결제 방식으로 카드, 실시간 계좌이체, 가상계좌, 휴대폰 소액결제, 상품권 결제, 간편결제 등의 방식으로 결제를 진행할 수 있습니다.

## <Highlight text="정기결제" />

비인증결제의 한 종류로 반복적인 구독결제를 위해 최초 1회 카드정보를 등록하여 **저장** 후 결제하는 방식을 의미합니다.

정기 · 구독 결제나 수기결제로 구분되며 인증과정 없이도 결제를 진행할 수 있어 간편하다는 장점이 있지만, 구매자 인증 과정이 생략되는만큼 결제 보안의 이슈가 발생할 확률이 높아 결제대행사 가입 시 입점심사가 까다롭게 진행된다는 점 참고해주세요.

### **정기결제의 범위**

용어상으로는 구독과 같은 '정기적인' 결제서비스를 의미하는 듯 하나 실질적으로 최초 1회 고객의 결제정보를 등록하고 이를 저장하면 모두 정기결제 라고 할 수 있습니다. 정기적이지 않은 비 정기적인 결제도 결제정보를 등록해놓고 추후에 재사용하는 구조라면 정기결제에 속하게 되는 것입니다.

현재 포트원에서 제공드리는 정기결제는 카드와 휴대폰결제로 가능합니다.

<Indent level="1">

- 정기적인 결제의 예시 : 멜론 스트리밍 자동결제, 잡지 월간구독, Youtube 프리미엄
- 비 정기적인 결제의 예시 : 카카오 택시 , 공유 킥보드 서비스, 기타 종량제 과금 서비스

</Indent>

### **정기결제 연동방식**

연동방식은 고객이 처음 카드를 등록하는 단계에서 **결제창방식** 과 **API 방식**으로 구분됩니다. 첫 카드 등록 이후 두 번째 결제부터는 모두 동일하게 API 방식으로 동작합니다.

결제창 방식 : 결제대행사의 결제창을
띄워서 카드정보를 등록하는 방식을 의미합니다.

<Indent level="1">

- 신용카드 정기결제(결제창) : PG사 결제창 안에서 **카드정보를 입력**하여 빌링키를 발급받음
- 신용카드 수기결제(결제창) : PG사 결제창 안에서 **카드정보를 입력**하여 일회성 결제를 시도함
- 휴대폰 소액결제 정기결제 : PG사 결제창 안에서 **휴대폰정보를 입**력하여 빌링키를 발급받음

</Indent>

API 방식 : 서버에서 API호출만으로
결제되는 방식 (결제화면 UI는 고객사에서 구현해주셔야 합니다)

<Indent level="1">

- 신용카드 정기결제(API) : 카드정보를 입력하는 UI를 직접 구현하여 API 호출로 빌링키를 발급받음
- 신용카드 수기결제(API) : 카드정보를 입력하는 UI를 직접 구현하여 API 호출로 일회성 결제를 시도함

</Indent>





<Callout content="휴대폰 정기결제 특징
- 전월 결제일 기준 +/- 5일 이내 결제되어야 합니다.
- 결제금액은 전(前) 월과 동일해야 합니다.
- 구매자 정보도 전(前) 월과 동일해야 하여 결제요청시 지정하는 구매자 정보(buyer_tel, email 등) 를 동일하게 설정해야 합니다.
- 매 달 1번씩 결제가 이루어져야 합니다.
ex) 9월01일에 결제 → 반드시 10월달에 거래되어야 합니다.
- 결제가 이루어지지 않은 달이 있다면 카드등록(빌링키발급) 단계인 처음부터 새롭게 진행해주셔야 합니다. " title="참고사항" icon="💡" />

<Callout title="비인증결제(정기+수기)지원 결제대행사 보러가기 ↗" />

## <Highlight text="해외결제" />

해외 고객을 위한 해외 발급 카드 및 국가별 현지 결제수단으로 결제하는 방식을 의미합니다.

해외 카드는 해외 결제 중 기본으로 대부분 결제대행사에서 지원 가능하며, 국가별 지원 가능한 현지 결제수단 및 간편결제는 결제대행사별로 지원 여부가 상이하므로 계약 전 확인하신 후 진행하시는 걸 권장드립니다.

<Callout content="" title="해외결제 지원 결제대행사 목록 보러가기↗" />
